==> eiffelstudio-18.07.10.1981.tar: F_code/C1/ch9.h <==

#ifndef _C1_ch9_
#define _C1_ch9_

#ifdef __cplusplus
extern "C" {
#endif

extern void F11_68(EIF_REFERENCE);
extern EIF_CHARACTER_32 F11_81(EIF_REFERENCE, EIF_CHARACTER_32);
RTOSHF (EIF_REFERENCE,93)
static EIF_REFERENCE F11_93_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_93(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,94)
static EIF_REFERENCE F11_94_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_94(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,95)
static EIF_REFERENCE F11_95_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_95(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,96)
static EIF_REFERENCE F11_96_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_96(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,97)
static EIF_REFERENCE F11_97_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_97(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,98)
static EIF_REFERENCE F11_98_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_98(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,99)
static EIF_REFERENCE F11_99_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_99(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,100)
static EIF_REFERENCE F11_100_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_100(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,101)
static EIF_REFERENCE F11_101_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_101(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,102)
static EIF_REFERENCE F11_102_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_102(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,103)
static EIF_REFERENCE F11_103_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_103(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,104)
static EIF_REFERENCE F11_104_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_104(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,105)
static EIF_REFERENCE F11_105_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_105(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,106)
static EIF_REFERENCE F11_106_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_106(EIF_REFERENCE);
extern void EIF_Minit9(void);
extern EIF_REFERENCE F633_3070(EIF_REFERENCE);
extern EIF_REFERENCE F634_3070(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C1/ch9.h <==

#ifndef _C1_ch9_
#define _C1_ch9_

#ifdef __cplusplus
extern "C" {
#endif

extern void F11_68(EIF_REFERENCE);
extern EIF_CHARACTER_32 F11_81(EIF_REFERENCE, EIF_CHARACTER_32);
RTOSHF (EIF_REFERENCE,93)
static EIF_REFERENCE F11_93_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_93(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,94)
static EIF_REFERENCE F11_94_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_94(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,95)
static EIF_REFERENCE F11_95_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_95(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,96)
static EIF_REFERENCE F11_96_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_96(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,97)
static EIF_REFERENCE F11_97_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_97(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,98)
static EIF_REFERENCE F11_98_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_98(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,99)
static EIF_REFERENCE F11_99_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_99(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,100)
static EIF_REFERENCE F11_100_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_100(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,101)
static EIF_REFERENCE F11_101_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_101(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,102)
static EIF_REFERENCE F11_102_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_102(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,103)
static EIF_REFERENCE F11_103_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_103(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,104)
static EIF_REFERENCE F11_104_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_104(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,105)
static EIF_REFERENCE F11_105_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_105(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,106)
static EIF_REFERENCE F11_106_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_106(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,107)
static EIF_REFERENCE F11_107_body(EIF_REFERENCE);
extern EIF_REFERENCE F11_107(EIF_REFERENCE);
extern void EIF_Minit9(void);
extern EIF_REFERENCE F618_3105(EIF_REFERENCE);
extern EIF_REFERENCE F617_3105(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
